@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 
 import os
+
 from superjson import json
+
 from .helper import HOME
+from .js_helper import create_json_if_not_exists, set_value, get_value, del_key, strip_comments
 from .singleton import CachedSpam
-from .js_helper import create_json_if_not_exists, set_value, get_value, del_key
 
 DEFAULT_JSON_SECRET_FILE = os.path.join(HOME, ".pysecret.json")
 
@@ -19,7 +21,7 @@ class JsonSecret(CachedSpam):
         self.secret_file = secret_file
         create_json_if_not_exists(self.secret_file)
         with open(self.secret_file, "rb") as f:
-            self.data = json.loads(f.read().decode("utf-8"))
+            self.data = json.loads(strip_comments(f.read().decode("utf-8")))
 
     def set(self, json_path, value):
         set_value(self.data, json_path, value)
